@@ -1,13 +1,13 @@
 #[derive(Copy,Debug,Clone)]
 pub enum Endian {
     BigEndian,
-    LittleEndtian,
+    LittleEndian,
 }
 
 pub(crate) fn system_endian() -> Endian {
     if cfg!(tarread_endian = "big") {
         Endian::BigEndian
     } else {
-        Endian::LittleEndtian
+        Endian::LittleEndian
     }
 }
\ No newline at end of file
